encode_get_bus_stops

Function encode_get_bus_stops 

pub fn encode_get_bus_stops(
    input: GetBusStopsInput,
) -> Result<Request<Vec<u8>>, Error>
Returns detailed information for all bus stops currently being serviced by buses, including bus stop codes and location coordinates.

Update freq: Ad-Hoc