get_bus_stops_parts

Function get_bus_stops_parts 

pub fn get_bus_stops_parts(
    input: GetBusStopsInput,
) -> Result<RequestParts<()>, Error>
Returns detailed information for all bus stops currently being serviced by buses, including bus stop codes and location coordinates.

Update freq: Ad-Hoc